@@ -15,7 +15,7 @@ use Mozilla::CA;
 use Scalar::Util;
 use XML::LibXML;
 
-our $VERSION = '1.0.1';
+our $VERSION = '1.0.2';
 
 use constant ENDPOINTS => {
     'IMGUR'           => 'https://api.imgur.com/3',
@@ -845,6 +845,7 @@ ImgurAPI::Client - Imgur API client
 This is a client module for interfacing with the Imgur API.
 
 =head1 SYNOPSIS
+
 =head2 Instantiation
 
     use ImgurAPI::Client;
@@ -865,24 +866,27 @@ After registering a client application with Imgur L<here|https://api.imgur.com/o
 
 =head2 Authentication
 
-The client can be authenticated by setting the access token and client id. The access token can be set using the C<set_access_token> method and the client id can be set using the C<set_client_id> method, or by passing them in constructor args.
+The client can be authenticated by setting the access token and client id. Those can be set a couple of ways. The first way is to do it is by passing them to the constructor:
 
-    my $client = ImgurAPI::Client->new;
-    $client->set_access_token('your_access_token');
-    $client->set_client_id('your_client_id');
-    # OR
     my $client = ImgurAPI::Client->new({
         'client_id'    => 'your_client_id',
         'access_token' => 'your_access_token'
     });
 
+The second way is to use the setter methods:
+
+    $client->set_access_token('your_access_token');
+    $client->set_client_id('your_client_id');
+
 =head2 METHODS
+
 =head3 new
 
     $client = ImgurAPI::Client->new(\%args);
 
 Valid constructor args are:
 
+=for :list
 * C<client_id> - Client identifier used for authorization, refresh token requests and unauthenticated requests.
 * C<client_secret> - Client secret used for acquiring a refresh token.
 * C<access_key> - Access token used to authenticate requests.
